Batch Module
------------

.. automodule:: viqa.batch_mode
    :exclude-members: BatchMetrics


.. rubric:: Classes

.. currentmodule:: viqa.batch_mode

.. autosummary::
    :toctree: generated/
    :template: class.rst

    BatchMetrics